@@ -5,10 +5,13 @@
 """
 PMAW: Pushshift Multithread API Wrapper
 """
-__version__ = '0.1.2'
+__version__ = '1.0.0'
 __author__ = 'Matthew Podolak'
 __license__ = 'MIT'
 
 from .RateLimit import RateLimit
+from .Request import Request
+from .Response import Response
+from .Cache import Cache
 from .PushshiftAPIBase import PushshiftAPIBase
 from .PushshiftAPI import PushshiftAPI
